c ######################################################################
c #
c #               ALUMINUM PROPERTIES PACKAGE
c #               ---------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of pure Aluminium (Al)
c #
c ######################################################################


c ######################################################################
      real function dAl(T)
c ######################################################################
c #
c # Density of Aluminium
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # http://en.wikipedia.org/wiki/Aluminium
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dAl               x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dAl = 2700.0
c *

      return
      end
c ######################################################################
      real function cAl(T)
c ######################################################################
c #
c # Specific heat of Aluminium
c #
c # Range: 1 <= T <= 1000 K
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c # V.J. Johnson, Properties of Materials at Low Temperatures (Phase 1)
c # Pergamon Press, 1961
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cAl               x    specific heat                     J/Kg K
c #
c # Author : L.Bottura & C. Rosso at Cryosoft
c # Version: 3.5   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0,T1
      real     Tmin,Tmax
      real     a0,a1,a2,a3
      real     b0,b1,b2,b3,b4
      real     AA,BB,CC,DD,a,b,c,d,na,nb,nc,nd
      data     T0  /   13.0300576 / ,  T1  /  54.4990277  /
      data     a0  /  0.012034041 / ,  a1  /  0.039172353 /, 
     &         a2  /  0.002543257 / ,  a3  /  0.000771961 /
      data     b0  / -4.797655015 / ,  b1  /  1.249154424 /, 
     &         b2  / -0.105581366 / ,  b3  /  0.004593931 /, 
     &         b4  / -3.65654e-05 /
      data     AA  /   9143.27476 / ,  BB  /   -417.10708 / ,
     &         CC  /   400.787649 / ,  DD  /   -7722.6604 / 
      data     a   /  -18.6481086 / ,  b   /  -25.7545827 / ,
     &         c   /  -18.1481600 / ,  d   /  -5.44742024 / 
      data     na  /   0.73861474 / ,  nb  /   1.52610058 / ,
     &         nc  /   2.48698565 / ,  nd  /   3.70977399 / 
      data     Tmin / 1.0/, Tmax / 1000.0/
      save    

c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)
      
      if (TT.le.T0) then
         cAl = a0 + a1*TT + a2*TT**2 + a3*TT**3            
      elseif (TT.gt.T0 .and. TT.le.T1) then
         cAl = b0 + b1*TT + b2*TT**2 + b3*TT**3 + b4*TT**4      
      elseif(TT.gt.T1) then
         cAl = AA*TT   /(a+TT)**na + BB*TT**2/(b+TT)**nb + 
     &          CC*TT**3/(c+TT)**nc + DD*TT**4/(d+TT)**nd
      endif

c *
      return
      end
c ######################################################################
      real function kAl(T,B,RRR)
c ######################################################################
c #
c # Thermal conductivity of Aluminium
c #
c # Range: 0.1 <= T <= 933.45 K, 0 <= B <= 30 T,  1.5 <= RRR <= 30000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   kAl               x    thermal conductivity              W/m K
c #
c # Author : L.Bottura & C. Rosso at CryoSoft
c # Version: 3.5   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 933.45)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 30.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 30000.0)
      real     rho273
      parameter(rho273=2.48e-8)
      real     L0
      parameter(L0=2.443e-8)
      real     p1,p2,p3,p4,p5,p6
      parameter (p1=4.716e-8, p2=2.446, p3=623.6, 
     &           p4=-0.16   , p5=130.9, p6=2.5)

c * local variables   
      real     TT,BB,R
      real     rhozero,beta,p7,arga,argb,argd
      real     wt,wi0,wi,w0,wc,magr
      real     magrAl

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)

c *
      rhozero = rho273/(R-1.)

      beta    = rhozero/L0

      p7      = 0.8168/(beta/0.0003)**0.1661

      arga    = min((log(TT/380.0)/0.6)**2,30.0)
      argb    = min((log(TT/ 94.0)/0.5)**2,30.0)
      argd    = min((p5/TT)**p6,30.0)

      wc      = -0.0005*log(TT/330)*exp(-arga) -
     &           0.0013*log(TT/110)*exp(-argb)
      w0      = beta/TT          
      wi      = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-argd))+wc
      wi0     = p7*wi*w0/(wi+w0) 
      wt      = w0+wi+wi0

      magr    = magrAl(TT,BB,R)

c *
      kAl     = 1.0/(wt*magr)

c *
      return
      end
c ######################################################################
      real function rAl(T,B,RRR)
c ######################################################################
c #
c # Electrical resistivity of Aluminium
c #
c # Range: 0.1 <= T <= 933.45 K, 0 <= B <= 30 T,  1.5 <= RRR <= 30000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   rAl               x    resistivity                       Ohm m
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 3.5   October 2012
c #
c ######################################################################
      implicit none
c *
      real     t,b,rrr

c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 933.45)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 30.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 30000.0)
      real     rho273
      parameter(rho273=2.48e-8)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter (p1=0.09052e-16, p2=4.551, p3=5.173e10,
     &           p4=-1.26, p5=13.64, p6=1.0, p7=0.7416)

c * local variables   
      real     TT,BB,R,rhozero,arg,rhoi,rhoi0,rho0,magr
      real     magrAl

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)
	
c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * resistivity at the temperature t
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * transverse magneto-resistance factor
      magr    = magrAl(TT,BB,R)

c * resistivity
      rAl     = magr * rho0
	
c *
      return
      end
c ######################################################################
c #
c # Auxiliary functions and calculations
c #
c ######################################################################

c ######################################################################
      real function magrAl(T,B,RRR)
c ######################################################################
c #
c # Magneto-resistivity factor of Aluminium, given as the ratio between
c # resistivity in transverse magnetic field b to resistivity at zero 
c # field
c #
c # Range: 0.1 <= T <= 933.45 K, 0 <= B <= 30 T,  1.5 <= RRR <= 30000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   magrAl            x    magneto-resistivity factor        -
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 1.1   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 933.45)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 30.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 30000.0)
      real     brrmin,brrmax
      parameter(brrmin = 0.0, brrmax = 40.0e3)
      real     rho273,rhorrr
      parameter(rho273=2.48e-8,rhorrr=4.52e-8)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter (p1=0.09052e-16, p2=4.551, p3=5.173e10,
     &           p4=-1.26, p5=13.64, p6=1.0, p7=0.7416)
      real     g1,g2,g3,g4,g5,g6,g7
      parameter (g1 = 0.116587e-04, g2 = 0.776391e-01, 
     &           g3 = 0.687100e+00, g4 = 0.536580e-05, 
     &           g5 = 0.135597e+01, g6 = 0.534860e-05, 
     &           g7 = 0.181991e+01)

c * local variables   
      real     TT,BB,R,rhozero,rhoice,arg,rhoi,rhoi0,rho0,rr,brr,magr

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)

c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * fit for the resistivity at the ice temperature 
      rhoice  = rho273 + rhorrr/R

c * resistivity at the temperature t
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * resistivity ration at temperature t
      rr      = rhoice/rho0   

c * product of field and residual resistivity ratio
      brr     = BB*rr
      brr     = max(brr,brrmin)
      brr     = min(brr,brrmax)
	
c * fit for the transverse magneto-resistance increase
      if(brr .gt. 1.) then
         magr = g1*rr**(g2*TT**g3)*brr**g7*(1+g4*brr)/
     &          (TT**g5*(1+g6*brr**g7)) 
      else
         magr = 0.0
      endif

c * transverse magneto-resistance factor
      magrAl  = magr + 1.0
	
c *
      return
      end
