c ######################################################################
c #
c #                   MANGANESE PROPERTIES PACKAGE
c #                   ----------------------------
c #
c # Contains functions for the calculation of the thermo-physical
c # properties of pure Manganese (Mn)
c #
c ######################################################################

c ######################################################################
      real function dMn(T)
c ######################################################################
c #
c # Density of Manganese
c #
c # Range: 0 <= T <= 1519 K
c #
c #                        References
c #                        ----------
c # http://en.wikipedia.org/wiki/Manganese
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dMn               x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dMn = 7210.0
c *

      return
      end
c ######################################################################
      real function cMn(T)
c ######################################################################
c #
c # Specific heat of Manganese
c #
c # Range: 1 <= T <= 900 K
c #
c #                        References
c #                        ----------
c # Malkov (1 to 20 K)
c # Toloukian crv 9 (12 to 298 K) and crv 5 shifted (300 to 900 K)
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cMn               x    specific heat                     J/Kg K
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0,T1
      real     Tmin,Tmax
      real     a1,a2,a3
      real     b0,b1,b2,b3,b4
      real     AA,BB,CC,a,b,c,na,nb,nc
      data     T0  /  13.18748185 / ,  T1  /  43.04374877 /
      data     a1  /   0.25008781 / ,  a2  /  -0.00098341 / , 
     &         a3  /   0.00042307 /
      data     b0  /  -7.499914804 / ,  b1  /  1.923486149 / , 
     &         b2  /  -0.140172906 / ,  b3  /  0.005277091 / ,
     &         b4  /  -4.93961E-05 /
      data     AA  / 803.11507623 / ,  BB  / -83.20337048 / ,
     &         CC  / -25.47928725 /
      data     a   /  10.48518912 / ,  b   /  3.047203090 / ,  
     &         c   /3124.22837016 /
      data     na  /   8.58084902 / ,  nb  /  5.574661389 / , 
     &         nc  /   5.00000000 /
      data     Tmin / 1.0/, Tmax / 900.0/
      Save


c * local variables   
      real     TT

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)
      
      if (TT.le.T0) then
         cMn = a1*TT + a2*TT**2 + a3*TT**3            
      elseif (TT.gt.T0 .and. TT.le.T1) then
         cMn = b0 + b1*TT+ b2*TT**2 + b3*TT**3 + b4*TT**4      
      elseif(TT.gt.T1) then
         cMn = AA*TT**na /(a+TT)**na + BB*TT**nb / (b+TT)**nb +
     &         CC*TT**nc /(c+TT)**nc
      endif

c *
      return
      end
c ######################################################################
      real function kMn(T,B,RRR)
c ######################################################################
c #
c # Thermal conductivity of Manganese
c #
c # Range: 2 <= T <= 300 K, no B dependence, no RRR dependence
c #
c #                        References
c #                        ----------
c # C.Y. Ho, R.W. Powell, P.E.Liley, Thernal Conductivity of the 
c # Elements, J. Phys. Chem. Ref. Data, 1 (2), 1972
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   kMn               x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables      
      real     AA,a,na
      real     Tmin,Tmax
      data     AA  / 11.15182809 / 
      data     a   / 207.1275485 / 
      data     na  / 0.622090779 /
      data     Tmin / 2.0/, Tmax / 300.0/
      save
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)
      
      kMn = AA*TT**na / (a+TT)**na
c *

      return
      end
c ######################################################################
      real function rMn(T,B,RRR)
c ######################################################################
c #
c # Electrical resistivity of Manganese
c #
c # Range: 1 <= T <= 700 K, no B dependence, based on RRR=20.8 data
c #
c #                        References
c #                        ----------
c # P.D. Desai, H.M. James and C.Y.Ho, Electrical Resistivity of 
c # Aluminum and Manganese, J. Phys. Chem. Ref. Data, 13(4), 1131-1172, 
c # 1984
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   rMn               x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 1, Tmax   = 700.0)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 0.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 1000.0)
      real     rho273
      parameter(rho273=143.e-8)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter(p1=1.600793422E-12, p2=2.478023947, p3=1.00e8,
     &          p4=0.200418218,     p5=995,         p6=-0.484412321, 
     &          p7=259.7372926)
c * local variables   
      real     TT,BB,R,rhozero,arg,rhoi,rhoi0,rho0,magr

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)
	
c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * resistivity at the temperature t
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * transverse magneto-resistance factor - not used (no data)
      magr    = 1.0

c * resistivity
      rMn     = magr * rho0
	
c *
      return
      end
